==> openshift-model-5.0.3-sources.jar: annotations/io/fabric8/openshift/api/model/SourceStrategyOptionsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SourceStrategyOptionsBuilder extends SourceStrategyOptionsFluentImpl<SourceStrategyOptionsBuilder> implements VisitableBuilder<SourceStrategyOptions,SourceStrategyOptionsBuilder> {

    SourceStrategyOptionsFluent<?> fluent;
    Boolean validationEnabled;

    public SourceStrategyOptionsBuilder() {
        this(true);
    }

    public SourceStrategyOptionsBuilder(Boolean validationEnabled) {
        this(new SourceStrategyOptions(), validationEnabled);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptionsFluent<?> fluent) {
        this(fluent, true);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptionsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SourceStrategyOptions(), validationEnabled);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptionsFluent<?> fluent,SourceStrategyOptions instance) {
        this(fluent, instance, true);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptionsFluent<?> fluent,SourceStrategyOptions instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withIncremental(instance.getIncremental()); 
        this.validationEnabled = validationEnabled; 
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptions instance) {
        this(instance,true);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptions instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withIncremental(instance.getIncremental()); 
        this.validationEnabled = validationEnabled; 
    }

    public SourceStrategyOptions build() {
        SourceStrategyOptions buildable = new SourceStrategyOptions(fluent.isIncremental());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SourceStrategyOptionsBuilder that = (SourceStrategyOptionsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/SourceStrategyOptionsBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class SourceStrategyOptionsBuilder extends SourceStrategyOptionsFluentImpl<SourceStrategyOptionsBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<SourceStrategyOptions,SourceStrategyOptionsBuilder> {

    SourceStrategyOptionsFluent<?> fluent;
    Boolean validationEnabled;

    public SourceStrategyOptionsBuilder() {
        this(true);
    }

    public SourceStrategyOptionsBuilder(Boolean validationEnabled) {
        this(new SourceStrategyOptions(), validationEnabled);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptionsFluent<?> fluent) {
        this(fluent, true);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptionsFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new SourceStrategyOptions(), validationEnabled);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptionsFluent<?> fluent,SourceStrategyOptions instance) {
        this(fluent, instance, true);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptionsFluent<?> fluent,SourceStrategyOptions instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withIncremental(instance.getIncremental()); 
        this.validationEnabled = validationEnabled; 
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptions instance) {
        this(instance,true);
    }

    public SourceStrategyOptionsBuilder(SourceStrategyOptions instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withIncremental(instance.getIncremental()); 
        this.validationEnabled = validationEnabled; 
    }

    public SourceStrategyOptions build() {
        SourceStrategyOptions buildable = new SourceStrategyOptions(fluent.getIncremental());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        SourceStrategyOptionsBuilder that = (SourceStrategyOptionsBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
